@@ -144,7 +144,7 @@ class ObjectData(models.Model):
     object_id = models.PositiveIntegerField(db_index=True,
             verbose_name=_('object id'))
     content_object = generic.GenericForeignKey('content_type',
-            'object_id', verbose_name=_('content'))
+            'object_id')
 
     class Meta:
         unique_together = (('journal', 'tag'),)
