@@ -2,8 +2,11 @@ from django.test import TestCase
 from django.contrib.auth.models import User, Group
 from django.db import transaction
 
+
 from . import record
-import models
+from . import actions
+from . import models
+
 
 class JournalTestCase(TestCase):
     def setUp(self):
@@ -39,3 +42,15 @@ class JournalTestCase(TestCase):
         for i, event in zip(range(20), models.Journal.objects.for_tag('logout').order_by('id')):
             self.assertEqual(unicode(event), 'user{0} logged out'.format(i))
 
+    def test_export_as_csv(self):
+        qs = models.Journal.objects.all()
+        l = list(actions.export_as_csv_generator(qs))
+        self.assertEquals(set(l[0]), set(['time', 'tag', 'message', 'group', 'group__id', 'user', 'user__id', 'user1', 'user1__id', 'user2', 'user2__id']))
+        l = list(actions.export_as_csv_generator(qs[:5]))
+        self.assertEquals(set(l[0]), set(['time', 'tag', 'message', 'user', 'user__id']))
+        for user in self.users:
+            user.delete()
+        qs = models.Journal.objects.all()
+        l = list(actions.export_as_csv_generator(qs))
+        self.assertEquals(l[1]['user'], '<deleted>')
+
